==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OdplatnoscSkladnik.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OdplatnoscSkladnik extends GenericDPSObject {
    /**
     * ODPLATNOSC_SKLADNIK.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ODPLATNOSC_SKLADNIK.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaId;

    /**
     * ODPLATNOSC_SKLADNIK.ODPLATNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long odplatnoscId;

    /**
     * ODPLATNOSC_SKLADNIK.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA_DZIEN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaDzien;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC_SKLADNIK.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPLATNOSC_SKLADNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.INSTYTUCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * ODPLATNOSC_SKLADNIK.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.ODPLATNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOdplatnoscId() {
        return odplatnoscId;
    }

    /**
     * ODPLATNOSC_SKLADNIK.ODPLATNOSC_ID
     *
     * @param odplatnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdplatnoscId(Long odplatnoscId) {
        this.odplatnoscId = odplatnoscId;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ODPLATNOSC_SKLADNIK.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.KWOTA_DZIEN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaDzien() {
        return kwotaDzien;
    }

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA_DZIEN
     *
     * @param kwotaDzien
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaDzien(BigDecimal kwotaDzien) {
        this.kwotaDzien = kwotaDzien;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdplatnoscSkladnik other = (OdplatnoscSkladnik) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOdplatnoscId() == null ? other.getOdplatnoscId() == null : this.getOdplatnoscId().equals(other.getOdplatnoscId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKwotaDzien() == null ? other.getKwotaDzien() == null : this.getKwotaDzien().equals(other.getKwotaDzien()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOdplatnoscId() == null) ? 0 : getOdplatnoscId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKwotaDzien() == null) ? 0 : getKwotaDzien().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", odplatnoscId=").append(odplatnoscId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", kwota=").append(kwota);
        sb.append(", kwotaDzien=").append(kwotaDzien);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OdplatnoscSkladnik.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OdplatnoscSkladnik extends GenericDPSObject {
    /**
     * ODPLATNOSC_SKLADNIK.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ODPLATNOSC_SKLADNIK.INSTYTUCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaId;

    /**
     * ODPLATNOSC_SKLADNIK.ODPLATNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long odplatnoscId;

    /**
     * ODPLATNOSC_SKLADNIK.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA_DZIEN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaDzien;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC_SKLADNIK.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPLATNOSC_SKLADNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.INSTYTUCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaId() {
        return instytucjaId;
    }

    /**
     * ODPLATNOSC_SKLADNIK.INSTYTUCJA_ID
     *
     * @param instytucjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaId(Long instytucjaId) {
        this.instytucjaId = instytucjaId;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.ODPLATNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOdplatnoscId() {
        return odplatnoscId;
    }

    /**
     * ODPLATNOSC_SKLADNIK.ODPLATNOSC_ID
     *
     * @param odplatnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdplatnoscId(Long odplatnoscId) {
        this.odplatnoscId = odplatnoscId;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ODPLATNOSC_SKLADNIK.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return ODPLATNOSC_SKLADNIK.KWOTA_DZIEN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaDzien() {
        return kwotaDzien;
    }

    /**
     * ODPLATNOSC_SKLADNIK.KWOTA_DZIEN
     *
     * @param kwotaDzien
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaDzien(BigDecimal kwotaDzien) {
        this.kwotaDzien = kwotaDzien;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdplatnoscSkladnik other = (OdplatnoscSkladnik) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInstytucjaId() == null ? other.getInstytucjaId() == null : this.getInstytucjaId().equals(other.getInstytucjaId()))
            && (this.getOdplatnoscId() == null ? other.getOdplatnoscId() == null : this.getOdplatnoscId().equals(other.getOdplatnoscId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKwotaDzien() == null ? other.getKwotaDzien() == null : this.getKwotaDzien().equals(other.getKwotaDzien()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInstytucjaId() == null) ? 0 : getInstytucjaId().hashCode());
        result = prime * result + ((getOdplatnoscId() == null) ? 0 : getOdplatnoscId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKwotaDzien() == null) ? 0 : getKwotaDzien().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", instytucjaId=").append(instytucjaId);
        sb.append(", odplatnoscId=").append(odplatnoscId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", kwota=").append(kwota);
        sb.append(", kwotaDzien=").append(kwotaDzien);
        sb.append("]");
        return sb.toString();
    }
}
